stalker.core.models.Note — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.models.Note

class `stalker.core.models.` `Note`(content='', **kwargs)

  Bases: `stalker.core.models.SimpleEntity`

  To leave notes about the connected node

  To leave notes in Stalker use the Note class

  Parameters: | content – the content of the note

  `__init__`(content='', **kwargs)

  Methods

  `__init__`(**kwargs[, content]) |

  Attributes

  `code` | The code name of this object.
  `content` | content is a string representing the content of this Note,
  `created_by` | The `User` who has created this object.
  `date_created` | A `datetime.datetime` instance showing the creation date and time of this object.
  `date_updated` | A `datetime.datetime` instance showing the update date and time of this object.
  `description` | Description of this object.
  `name` | Name of this object
  `nice_name` | Nice name of this object.
  `type` | The type of the object.
  `updated_by` | The `User` who has updated this object.

  `content`

    content is a string representing the content of this Note, can be given as an empty string or can be even None, but anything other than None or string or unicode will raise a TypeError

  `code`

    The code name of this object.

    It accepts string or unicode values and any other kind of objects will be converted to string. In any update to the name attribute the code also will be updated. If the code is not initialized or given as None, it will be set to the uppercase version of the nice_name attribute. Setting the code attribute to None will reset it to the default value. The default value is the upper case form of the nice_name.

  `created_by`

    The `User` who has created this object.

  `date_created`

    A `datetime.datetime` instance showing the creation date and time of this object.

  `date_updated`

    A `datetime.datetime` instance showing the update date and time of this object.

  `description`

    Description of this object.

  `name`

    Name of this object

  `nice_name`

    Nice name of this object.

    It has the same value with the name (contextually) but with a different format like, all the white spaces replaced by underscores (“_”), all the CamelCase form will be expanded by underscore (_) characters and it is always lower case.

    There is also the `code` attribute which is simply the upper case form of `nice_name` if it is not defined differently (i.e set to another value).

  `type`

    The type of the object.

    It is an instance of `Type` with a proper `target_entity_type`.

  `updated_by`

    The `User` who has updated this object.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »